@@ -1,14 +1,14 @@
 cm3 <-
-function(rtot=NULL,ctot=NULL,m,tol=1e-05,maxit=500,iter=FALSE)
+function(rtot=NULL,ctot=NULL,m,tol=1e-05,maxit=500,verbose=FALSE)
 {
   if(round(sum(rtot))!=round(sum(ctot)))
     stop("row and column totals are not equal, ensure sum(rtot)==sum(ctot)")
   i<-dim(m)[1];  j<-dim(m)[2]
   alpha <- rep(1,i)
   beta <- rep(1,j)
-  if(iter==TRUE){
+  if(verbose==TRUE){
     rd<-paste("%.",nchar(format(tol,scientific=FALSE))-2,"f",sep="")
-    cat(sprintf(rd,c(alpha,beta)), fill = T)
+    cat(sprintf(rd,c(alpha,beta)), fill = TRUE)
   }
   alpha.old <- alpha+1; beta.old <- beta+1
   it<-1;  max.diff<-tol*2
@@ -23,8 +23,8 @@ function(rtot=NULL,ctot=NULL,m,tol=1e-05,maxit=500,iter=FALSE)
     }
     it<-it+1
     max.diff<-max(abs(alpha-alpha.old), abs(beta-beta.old))
-    if(iter==TRUE)
-      cat(sprintf(rd,c(alpha,beta)), fill = T)
+    if(verbose==TRUE)
+      cat(sprintf(rd,c(alpha,beta)), fill = TRUE)
   }
   return(list(N=c(alpha%*%t(beta))*m,
               theta=c(mu=1,alpha=alpha,beta=beta)))
